import * as uuid from "uuid";
import { ICanvasData } from "../components";

export interface IGraphClipBoard {
  write(data: ICanvasData): void;
  read(): ICanvasData | null;
}

export const COPIED_NODE_SPACING = 50;

export class DefaultClipboard implements IGraphClipBoard {
  private readonly storage: Storage;

  constructor(storage: Storage) {
    this.storage = storage;
  }

  public write(data: ICanvasData): void {
    this.storage.setItem(
      "graph-clipboard",
      JSON.stringify({
        nodes: data.nodes.map(n => ({ ...n, data: {} })),
        edges: data.edges.map(e => ({ ...e, data: {} }))
      })
    );
  }

  public read(): ICanvasData | null {
    const str = this.storage.getItem("graph-clipboard");

    if (!str) {
      return null;
    }

    try {
      const data = JSON.parse(str) as ICanvasData;
      const nodeIdHash = new Map<string, string>();

      return {
        nodes: data.nodes.map(n => {
          const newId = uuid.v4();

          nodeIdHash.set(n.id, newId);

          return {
            ...n,
            x: n.x + COPIED_NODE_SPACING,
            y: n.y + COPIED_NODE_SPACING,
            id: newId
          };
        }),
        edges: data.edges.map(e => ({
          ...e,
          id: uuid.v4(),
          source: nodeIdHash.get(e.source) || "",
          target: nodeIdHash.get(e.target) || ""
        }))
      };
    } catch (error) {
      return null;
    }
  }
}
