import * as React from "react";
import {
  GraphPortConnectState,
  GraphPortState,
  ICanvasData,
  ICanvasPort
} from "../components";
import { IPortConfig, IPortDrawArgs, ITheme } from "../contexts";

export const defaultPort: IPortConfig = {
  getStyle(
    port: ICanvasPort,
    data: ICanvasData,
    theme: ITheme
  ): Partial<React.CSSProperties> {
    const stroke = theme.portStroke;
    let fill = theme.portFill;

    switch (port.connectState) {
      case GraphPortConnectState.connectedAsSource:
      case GraphPortConnectState.connectedAsTarget:
        fill = theme.connectedPortColor;
        break;
      default:
    }

    switch (port.state) {
      case GraphPortState.activated:
        fill = theme.primaryColor;
        break;
      default:
    }

    return {
      stroke,
      fill
    };
  },
  getIsConnectable(port: ICanvasPort, data: ICanvasData): boolean | undefined {
    return true;
  },
  render(args: IPortDrawArgs): React.ReactNode {
    const { model: port, data } = args;

    const style = defaultPort.getStyle
      ? defaultPort.getStyle(port, data, args.theme)
      : {};

    const { x, y } = args;
    const polygonPoints = `${x - 5} ${y}, ${x + 7} ${y}, ${x + 1} ${y + 8}`;

    return (
      <>
        {port.connectState === GraphPortConnectState.connectedAsTarget ? (
          <polygon points={polygonPoints} style={style} />
        ) : (
          <circle
            key={`${args.parentNode.id}-${args.model.id}`}
            r={5}
            cx={x}
            cy={y}
            style={style}
          />
        )}
      </>
    );
  }
};
