import { ICanvasNode, ICanvasPort } from "../components";
import { INodeDrawArgs, IRectConfig } from "../contexts";

export const withDefaultPortsPosition = (
  base: IRectConfig<ICanvasNode>
): IRectConfig<ICanvasNode> => {
  return {
    ...base,
    getPorts: (args: INodeDrawArgs): ICanvasPort[] => {
      const node = args.model;
      const rawPorts = base.getPorts ? base.getPorts(args) : node.ports;

      if (!rawPorts) {
        return [];
      }

      const inputPorts = rawPorts.filter(p => !p.isInputDisabled);
      const outputPorts = rawPorts.filter(p => p.isInputDisabled);
      const inputPortsCount = inputPorts.length;
      const outputPortsCount = outputPorts.length;
      const inputPortsInterval = 1 / (inputPortsCount + 1);
      const outputPortsInterval = 1 / (outputPortsCount + 1);
      const res: ICanvasPort[] = [];

      for (let i = 0; i < inputPortsCount; i++) {
        res.push({
          ...inputPorts[i],
          position: [(i + 1) * inputPortsInterval, 0]
        });
      }

      for (let i = 0; i < outputPortsCount; i++) {
        res.push({
          ...outputPorts[i],
          position: [(i + 1) * outputPortsInterval, 1]
        });
      }

      return res;
    }
  };
};
