import * as React from "react";
import { useTheme } from "../hooks";
import { getCurvePathD } from "../utils";

export interface IConnectingLine {
  x1: number;
  y1: number;
  x2: number;
  y2: number;
  visible: boolean;
}

interface IProps {
  connectingLine: IConnectingLine;
  autoAttachLine: IConnectingLine;
  styles?: React.CSSProperties;
}

export const ConnectingLine: React.FunctionComponent<IProps> = props => {
  const { autoAttachLine, connectingLine, styles } = props;
  const fixedX2 = connectingLine.x2 - 8;
  const fixedY2 = connectingLine.y2 - 13;

  const { theme } = useTheme();

  const strokeColor = styles?.stroke || theme.primaryColor;

  return (
    <g>
      <defs>
        <marker
          id="markerArrow"
          markerWidth="10"
          markerHeight="10"
          refX="6"
          refY="5"
          orient="auto"
          markerUnits="strokeWidth"
        >
          <path
            d="M0,0 L6,5 L0,10"
            style={{
              stroke: connectingLine.visible ? strokeColor : "none",
              fill: "none"
            }}
          />
        </marker>
      </defs>
      {/* connecting line */}
      <line
        x1={connectingLine.x1}
        y1={connectingLine.y1}
        x2={fixedX2}
        y2={fixedY2}
        style={{
          stroke: connectingLine.visible ? strokeColor : "none",
          fill: "none"
        }}
        markerEnd="url(#markerArrow)"
      />
      {/* temporary edge, for automatically attach effect*/}
      <path
        d={getCurvePathD(
          autoAttachLine.x2,
          autoAttachLine.x1,
          autoAttachLine.y2,
          autoAttachLine.y1
        )}
        style={{
          stroke: autoAttachLine.visible ? strokeColor : "none",
          fill: "none"
        }}
      />
    </g>
  );
};
