import * as React from "react";

interface IState {
  hasError: boolean;
  error?: Error;
  errorInfo?: React.ErrorInfo;
}

export class DefaultErrorBoundary extends React.Component<{}, IState> {
  constructor(props: {}) {
    super(props);
    this.state = { hasError: false };
  }

  public static getDerivedStateFromError(error: Error): Partial<IState> {
    return { hasError: true, error };
  }

  public componentDidCatch(error: Error, errorInfo: React.ErrorInfo): void {
    this.setState({
      error,
      errorInfo
    });
  }

  public render(): React.ReactNode {
    if (this.state.hasError) {
      const componentStackLines = this.state.errorInfo
        ? this.state.errorInfo.componentStack.split("\n")
        : [];

      return (
        <div style={{ color: "red" }}>
          <h1>Something went wrong.</h1>
          <p>{`Error: ${this.state.error}`}</p>
          <p>{`ErrorInfo: ${JSON.stringify(this.state.errorInfo)}`}</p>
          <h2>Component Stack</h2>
          {componentStackLines.map((line, index) => (
            <p key={index}>{line}</p>
          ))}
        </div>
      );
    }

    return this.props.children;
  }
}
