import {
  GraphAnnotationEvent,
  GraphCanvasEvent,
  GraphEdgeEvent,
  GraphNodeEvent,
  GraphPortEvent
} from "../common/GraphEvent.constant";

export type TSetData = React.Dispatch<React.SetStateAction<ICanvasData>>;

export interface ICanvasNode {
  shape?: string;
  x: number;
  y: number;
  name?: string;
  id: string;
  state?: GraphNodeState;
  isInSearchResults?: boolean;
  ports?: ICanvasPort[];
  // tslint:disable-next-line: no-any
  data?: any;
  height?: number;
  width?: number;
}

export enum GraphEdgeState {
  default = "default",
  selected = "selected"
}

export interface ICanvasEdge {
  shape?: string;
  source: string;
  target: string;
  sourcePortId: string;
  targetPortId: string;
  id: string;
  state?: GraphEdgeState;
}

export interface ICanvasPort {
  id: string;
  name: string;
  shape?: string;
  position?: [number, number];
  state?: GraphPortState;
  connectState?: GraphPortConnectState;
  isInputDisabled?: boolean;
  isOutputDisabled?: boolean;
}

export interface ICanvasAnnotation {
  shape?: string;
  x: number;
  y: number;
  name?: string;
  id: string;
  state?: GraphNodeState;
  // tslint:disable-next-line: no-any
  data?: any;
  height?: number;
  width?: number;
}

export enum GraphNodeState {
  default = "default",
  activated = "activated",
  selected = "selected",
  editing = "editing"
}

export enum GraphPortState {
  default = "default",
  selected = "selected",
  activated = "activated",
  connecting = "connecting"
}

export enum GraphPortConnectState {
  connectedAsSource = "connectedAsSource",
  connectedAsTarget = "connectingAsTarget"
}

export interface ICanvasData {
  nodes: ICanvasNode[];
  edges: ICanvasEdge[];
  annotations?: ICanvasAnnotation[];
}

// tslint:disable: no-any
export type GraphNodeEventProps = Record<
  GraphNodeEvent,
  (e: any, node: ICanvasNode) => void
>;

export type GraphEdgeEventProps = Record<
  GraphEdgeEvent,
  (e: any, edge: ICanvasEdge) => void
>;

export type GraphPortEventProps = Record<
  GraphPortEvent,
  (e: any, node: ICanvasNode, port: ICanvasPort) => void
>;

export type GraphAnnotationEventProps = Record<
  GraphAnnotationEvent,
  (e: any, annotation: ICanvasAnnotation) => void
>;

export type GraphCanvasEventProps = Record<GraphCanvasEvent, (e: any) => void>;
