import * as React from "react";
import { v4 as uuid } from "uuid";
import { graphController, GraphState } from "../../utils/graphController";
import { ICanvasNode } from "../Graph.interface";

interface IProps {
  style?: React.CSSProperties;
  className?: string;
  model: Partial<ICanvasNode>;
  shape?: string;
}

// for ItemPanel
export const Item: React.FunctionComponent<IProps> = props => {
  const { style, className, children, model, shape } = props;

  const onMouseDown = (evt: React.MouseEvent) => {
    evt.stopPropagation();

    graphController.setDraggingItem({
      model: { ...model, x: evt.clientX, y: evt.clientY, id: uuid() }
    });
    graphController.setDraggingShape(shape || model.shape);

    graphController.setGraphState(GraphState.addingNode);
  };

  const onMouseUp = () => {
    graphController.setGraphState(GraphState.default);
  };

  return (
    <div
      style={{ userSelect: "none", cursor: "pointer", ...style }}
      className={className}
      onMouseDown={onMouseDown}
      onMouseUp={onMouseUp}
      role="button"
    >
      {children}
    </div>
  );
};
