import * as React from "react";
import { useContextMenuConfigContext } from ".";
import { MenuType } from "../contexts";
import { useClientRect } from "./useClientRect";

// tslint:disable: no-any
export const useContextMenu = (
  isVisibleContextMenu: boolean,
  clientX: number,
  clientY: number
): [
  React.ReactNode | undefined,
  (value: React.SetStateAction<MenuType>) => void,
  boolean,
  (value: React.SetStateAction<boolean>) => void,
  ((node: any) => void) | null,
  {
    left: number | undefined;
    top: number | undefined;
    right: number | undefined;
    bottom: number | undefined;
  }
] => {
  const contextMenuConfig = useContextMenuConfigContext();
  const [isVisible, setIsVisible] = React.useState(isVisibleContextMenu);
  const [curMenuType, setCurMenuType] = React.useState();
  const [menuRect, menuRef] = useClientRect();

  const contextMenuEleMap = {
    [MenuType.Node]: contextMenuConfig.getMenu(MenuType.Node),
    [MenuType.Edge]: contextMenuConfig.getMenu(MenuType.Edge),
    [MenuType.Port]: contextMenuConfig.getMenu(MenuType.Port),
    [MenuType.Multi]: contextMenuConfig.getMenu(MenuType.Multi),
    [MenuType.Canvas]: contextMenuConfig.getMenu(MenuType.Canvas),
    [MenuType.Annotation]: contextMenuConfig.getMenu(MenuType.Annotation)
  };

  let left = clientX;
  let top = clientY;
  let right;
  let bottom;

  if (isVisible && menuRect) {
    const { clientWidth, clientHeight } = document.documentElement;
    const { width: menuWidth, height: menuHeight } = menuRect;

    if (clientX + menuWidth >= clientWidth) {
      left = 0;
      right = 0;
    }
    if (clientY + menuHeight >= clientHeight) {
      top = 0;
      bottom = 0;
    }
  }
  const menuPosition = { left, top, right, bottom };

  return [
    contextMenuEleMap[curMenuType],
    setCurMenuType,
    isVisible,
    setIsVisible,
    menuRef,
    menuPosition
  ];
};
