import * as React from "react";
import { pan, TSetZoomPanSettings, zoom } from "../utils/zoomAndPan";

import { useWindowEvent } from "./useWindowEvent";

interface IUseWheelHandlersOptions {
  svgRef: React.RefObject<SVGSVGElement>;
  setZoomPanSettings: TSetZoomPanSettings;
  getIsCanvasFocused(): boolean;
}

export const useWheelHandlers = (options: IUseWheelHandlersOptions) => {
  const onContainerWheel = (evt: WheelEvent) => {
    if (!options.getIsCanvasFocused()) {
      return;
    }

    evt.stopPropagation();
    evt.preventDefault();

    if (evt.ctrlKey) {
      const scale = evt.deltaY > 0 ? 1.1 : 0.9;

      zoom(scale, options.svgRef, options.setZoomPanSettings.bind(undefined));
    } else {
      pan(
        0,
        evt.deltaY < 0 ? 100 : -100,
        options.setZoomPanSettings.bind(undefined)
      );
    }
  };

  useWindowEvent("wheel", onContainerWheel, { passive: false });
};
