import { ICanvasNode, ICanvasPort, IGraphProps, TSetData } from "../components";

import { IGraphConfig } from "../contexts";
import { getNodeConfig } from "./getNodeConfig";
import { getRectHeight, getRectWidth } from "./layout";
import { getClientByPoint } from "./transformMatrix";

export const getPortPosition = (
  node: ICanvasNode,
  port: ICanvasPort,
  graphConfig: IGraphConfig,
  transformMatrix?: [number, number, number, number, number, number]
): { x: number; y: number } => {
  const nodeConfig = getNodeConfig(node, graphConfig);
  const width = getRectWidth<ICanvasNode>(nodeConfig, node);
  const height = getRectHeight<ICanvasNode>(nodeConfig, node);

  const xOffset = port.position ? port.position[0] * width : width * 0.5;
  const x = node.x + xOffset;
  const yOffset = port.position ? port.position[1] * height : height;
  const y = node.y + yOffset;

  return getClientByPoint(x, y, transformMatrix);
};

export const getPortPositionByPortId = (
  node: ICanvasNode,
  portId: string,
  graphConfig: IGraphConfig,
  graphProps: IGraphProps,
  setData: TSetData,
  transformMatrix?: [number, number, number, number, number, number] // matrix is for the svg has pan/zoom
): { x: number; y: number } => {
  const nodeConfig = getNodeConfig(node, graphConfig);

  const ports = nodeConfig.getPorts
    ? nodeConfig.getPorts({ model: node, graphProps, setData })
    : node.ports || [];

  const port = ports.filter(p => p.id === portId)[0];

  if (!port) {
    throw new Error(`invalid port id ${portId}`);
  }

  return getPortPosition(node, port, graphConfig, transformMatrix);
};
