import { IRectConfig } from "../contexts";
import { getTransformedPointByRealPoint } from "./transformMatrix";
import { IZoomPanSettings } from "./zoomAndPan";

export function getRectWidth<T extends { width?: number }>(
  rectConfig: IRectConfig<T>,
  rect: T
): number {
  const minWidth = rectConfig.getMinWidth(rect);

  if (rect.width && rect.width >= minWidth) {
    return rect.width;
  }

  return minWidth;
}

export function getRectHeight<T extends { height?: number }>(
  rectConfig: IRectConfig<T>,
  rect: T
): number {
  const minHeight = rectConfig.getMinHeight(rect);

  if (rect.height && rect.height >= minHeight) {
    return rect.height;
  }

  return minHeight;
}

export const getBoundaryPoints = (
  svgRef: React.RefObject<SVGSVGElement>,
  zoomAndPanSettings: IZoomPanSettings
): {
  minX: number;
  minY: number;
  maxX: number;
  maxY: number;
} => {
  if (!svgRef.current) {
    return {
      minX: 0,
      minY: 0,
      maxX: 0,
      maxY: 0
    };
  }

  const containerEl = svgRef.current.closest<HTMLDivElement>(
    ".react-dag-editor-container"
  );

  if (!containerEl) {
    return {
      minX: 0,
      minY: 0,
      maxX: 0,
      maxY: 0
    };
  }
  const { width, height } = containerEl.getBoundingClientRect();

  const { x: minX, y: minY } = getTransformedPointByRealPoint(
    0,
    0,
    zoomAndPanSettings.transformMatrix
  );

  const { x: maxX, y: maxY } = getTransformedPointByRealPoint(
    width,
    height,
    zoomAndPanSettings.transformMatrix
  );

  return {
    minX,
    minY,
    maxX,
    maxY
  };
};
