import { IZoomPanSettings } from "./zoomAndPan";

// tslint:disable-next-line: export-name
export const getClientByPoint = (
  x: number,
  y: number,
  transformMatrix?: [number, number, number, number, number, number]
) => {
  if (!transformMatrix) {
    return {
      x,
      y
    };
  }

  const realX =
    transformMatrix[0] * x + transformMatrix[2] * y + transformMatrix[4];
  const realY =
    transformMatrix[1] * x + transformMatrix[3] * y + transformMatrix[5];

  return {
    x: realX,
    y: realY
  };
};

export const getPointByClient = (
  x: number,
  y: number,
  transformMatrix?: [number, number, number, number, number, number]
): { x: number; y: number } => {
  if (!transformMatrix) {
    return {
      x,
      y
    };
  }

  const [a, b, c, d] = transformMatrix;
  const realDx = (d * x) / (a * d - b * c) + (c * y) / (b * c - a * d);
  const realDy = (b * x) / (b * c - a * d) + (a * y) / (a * d - b * c);
  return {
    x: realDx,
    y: realDy
  };
};

export const getTransformedPointByRealPoint = (
  realX: number,
  realY: number,
  transformMatrix?: [number, number, number, number, number, number]
) => {
  if (!transformMatrix) {
    return {
      x: realX,
      y: realY
    };
  }
  const [t0, t1, t2, t3, t4, t5] = transformMatrix;
  return {
    x: ((realX - t4) * t3 - (realY - t5) * t2) / (t0 * t3 - t1 * t2),
    y: ((realX - t4) * t1 - (realY - t5) * t0) / (t1 * t2 - t0 * t3)
  };
};

/**
 * adjust offset and transform
 * x: original event.clientX
 * y: original event.clientY
 * containerSvgRef: graph svg ref
 */
export const adjustedClientPoint = (
  x: number,
  y: number,
  svgRef: React.RefObject<SVGSVGElement>,
  zoomPanSettings: IZoomPanSettings
): [number, number] => {
  let adjustedX = x;
  let adjustedY = y;

  if (svgRef.current) {
    const { left, top } = svgRef.current.getBoundingClientRect();
    adjustedX = x - left;
    adjustedY = y - top;
  }

  const { x: transformedX, y: transformedY } = getTransformedPointByRealPoint(
    adjustedX,
    adjustedY,
    zoomPanSettings.transformMatrix
  );

  return [transformedX, transformedY];
};
