import { ICanvasData } from "../components";
import { debounce } from "./debounce";

export class DataStore {
  public debouncedRecord = debounce(this.record.bind(this), 100, this);
  private readonly past: ICanvasData[] = [];
  private present?: ICanvasData;
  private readonly future: ICanvasData[] = [];

  public undo(): ICanvasData | void {
    if (this.past.length === 0) {
      return undefined;
    }

    if (this.present) {
      this.future.unshift(this.present);
    }

    this.present = this.past.pop();

    return this.present;
  }

  public redo(): ICanvasData | void {
    if (this.future.length === 0) {
      return undefined;
    }

    if (this.present) {
      this.past.push(this.present);
    }

    this.present = this.future.shift();

    return this.present;
  }

  public record(data: ICanvasData): void {
    if (this.present) {
      this.past.push(this.present);
    }

    this.present = { ...data };

    if (this.future.length > 0) {
      this.future.splice(0, this.future.length);
    }
  }
}

export const dataStore = new DataStore();
