import { ICanvasData, ICanvasEdge, ICanvasNode } from "../components";
import { getEntityById } from "./graphDataUtils";
import { getClientByPoint } from "./transformMatrix";

// tslint:disable-next-line: export-name
export const isNodeInViewPort = (
  node: ICanvasNode,
  transformMatrix: [number, number, number, number, number, number]
): boolean => {
  const vWidth = Math.max(
    document.documentElement.clientWidth,
    window.innerWidth || 0
  );
  const vHeight = Math.max(
    document.documentElement.clientHeight,
    window.innerHeight || 0
  );

  const { x, y } = getClientByPoint(node.x, node.y, transformMatrix);

  return x > -200 && x < vWidth + 200 && y > -200 && y < vHeight + 200;
};

export const isEdgeInViewPort = (
  edge: ICanvasEdge,
  data: ICanvasData,
  transformMatrix: [number, number, number, number, number, number]
): boolean => {
  const sourceNode = getEntityById(edge.source, data.nodes);
  const targetNode = getEntityById(edge.target, data.nodes);

  return (
    isNodeInViewPort(sourceNode, transformMatrix) ||
    isNodeInViewPort(targetNode, transformMatrix)
  );
};
