import * as React from "react";
import * as uuid from "uuid";
import {
  AnnotationMenu,
  CanvasMenu,
  ContextMenu as $ContextMenu,
  EdgeMenu,
  MultiMenu,
  NodeMenu,
  PortMenu,
  usePropsAPI
} from "../../src";

export const ContextMenu: React.FunctionComponent = () => {
  const propsAPI = usePropsAPI();

  const onCopyClick = () => {
    propsAPI.copy();
  };
  const onPasteClick = (evt: React.MouseEvent) => {
    propsAPI.paste(evt.clientX, evt.clientY);
  };
  const onDeleteClick = () => {
    propsAPI.delete();
  };
  const onAddAnnotation = (evt: React.MouseEvent) => {
    propsAPI.addAnnotation({
      id: uuid.v4(),
      x: evt.clientX,
      y: evt.clientY,
      shape: "annotation"
    });
  };

  return (
    <$ContextMenu className="my-context-menu">
      <NodeMenu>
        <div onClick={onCopyClick} role="button">
          Copy
        </div>
        <div onClick={onDeleteClick} role="button">
          Delete
        </div>
      </NodeMenu>
      <EdgeMenu>
        <div onClick={onDeleteClick} role="button">
          Delete
        </div>
      </EdgeMenu>
      <PortMenu>
        <div>Visualization</div>
      </PortMenu>
      <MultiMenu>
        <div onClick={onCopyClick} role="button">
          Copy(multi)
        </div>
        <div onClick={onDeleteClick} role="button">
          Delete(multi)
        </div>
      </MultiMenu>
      <AnnotationMenu>
        <div onClick={onDeleteClick} role="button">
          Delete
        </div>
      </AnnotationMenu>
      <CanvasMenu>
        <div onClick={onAddAnnotation} role="button">
          Add annotation
        </div>
        <div onClick={onPasteClick} role="button">
          Paste
        </div>
      </CanvasMenu>
    </$ContextMenu>
  );
};
