import * as uuid from "uuid";

import { ICanvasData, IGraphClipBoard } from "../../src";

export class CustomClipboard implements IGraphClipBoard {
  public write(data: ICanvasData): void {
    window.localStorage.setItem(
      "graph-clipboard",
      JSON.stringify({
        nodes: data.nodes.map(n => ({
          ...n,
          data: { comment: n.data.comment, iconName: n.data.iconName }
        })),
        edges: data.edges.map(e => ({ ...e, data: {} }))
      })
    );
  }

  public read(): ICanvasData | null {
    const str = window.localStorage.getItem("graph-clipboard");

    if (!str) {
      return null;
    }

    try {
      const data = JSON.parse(str) as ICanvasData;
      const nodeIdHash = new Map<string, string>();

      return {
        nodes: data.nodes.map(n => {
          const newId = uuid.v4();

          nodeIdHash.set(n.id, newId);

          return {
            ...n,
            x: n.x + 50,
            y: n.y + 50,
            id: newId
          };
        }),
        edges: data.edges.map(e => ({
          ...e,
          id: uuid.v4(),
          source: nodeIdHash.get(e.source) || "",
          target: nodeIdHash.get(e.target) || ""
        }))
      };
    } catch (error) {
      return null;
    }
  }
}
