import * as React from "react";

interface IState {
  hasError: boolean;
  error?: Error;
  errorInfo?: React.ErrorInfo;
}

export class CustomErrorBoundary extends React.Component<{}, IState> {
  constructor({}) {
    super({});
    this.state = { hasError: false };
  }

  public static getDerivedStateFromError(error: Error): Partial<IState> {
    return { hasError: true, error };
  }

  public componentDidCatch(error: Error, errorInfo: React.ErrorInfo): void {
    this.setState({
      error,
      errorInfo
    });
  }

  public render(): React.ReactNode {
    if (this.state.hasError) {
      return (
        <>
          <h1>This is custom error boundary</h1>
          <p>{`Error: ${this.state.error}`}</p>
          <p>{`ErrorInfo: ${JSON.stringify(this.state.errorInfo)}`}</p>
        </>
      );
    }

    return this.props.children;
  }
}
