import { Stack } from "office-ui-fabric-react";
import * as React from "react";
import {
  ICanvasData,
  isSupported,
  IZoomPanSettings,
  Minimap,
  ReactDagEditor,
  RegisterNode,
  RegisterPanel,
  withDefaultPortsPosition
} from "../../src";
import { RegisterClipboard } from "../../src/components/RegisterClipboard";
import { RegisterPort } from "../../src/components/RegisterPort";
import { ContextMenu } from "./ContextMenu";
import { CustomClipboard } from "./CustomClipBoard";
import { InnerGraph } from "./InnerGraph";
import { ItemPanel } from "./ItemPanel";
import { moduleNode } from "./moduleNode";
import { modulePort } from "./modulePort";
import { overviewPanel } from "./overviewPanel";
import { Toolbar } from "./Toolbar";

interface IProps {
  initData: ICanvasData;
}

const clipboard = new CustomClipboard();

export const DemoGraph: React.FunctionComponent<IProps> = props => {
  if (!isSupported()) {
    return <h1>Browser not supported</h1>;
  }

  const [data, setData] = React.useState<ICanvasData>(props.initData);
  const [isMinimapVisible, setIsMinimapVisible] = React.useState<boolean>(
    false
  );
  const [zoomPanSettings, setZoomPanSettings] = React.useState<
    IZoomPanSettings
  >({ transformMatrix: [1, 0, 0, 1, 0, 0] });

  const scale = zoomPanSettings.transformMatrix[0];

  return (
    <ReactDagEditor>
      <RegisterNode
        name="module"
        config={withDefaultPortsPosition(moduleNode)}
      />
      <RegisterPort name="modulePort" config={modulePort} />
      <RegisterClipboard clipboard={clipboard} />
      <RegisterPanel name={"overview"} config={overviewPanel} />
      <Stack horizontal={true}>
        <Stack.Item>
          <ItemPanel />
        </Stack.Item>
        <Stack.Item>
          <div>
            <Toolbar
              scale={scale}
              isMinimapVisible={isMinimapVisible}
              setIsMinimapVisible={setIsMinimapVisible}
            />
            <InnerGraph
              data={data}
              setData={setData}
              zoomPanSettings={zoomPanSettings}
              setZoomPanSettings={setZoomPanSettings}
            />
          </div>
        </Stack.Item>
      </Stack>
      {isMinimapVisible && (
        <Minimap
          style={{
            position: "absolute",
            bottom: 400,
            right: 100,
            border: "1px solid #ccc"
          }}
        />
      )}
      <ContextMenu />
    </ReactDagEditor>
  );
};
