import * as React from "react";
import {
  Graph,
  GraphPortState,
  ICanvasData,
  ICanvasNode,
  ICanvasPort,
  IZoomPanSettings,
  RegisterPanel,
  TSetData,
  TSetZoomPanSettings,
  usePropsAPI
} from "../../src";
import { NodePanel } from "./NodePanel";
import { PortPanel } from "./PortPanel";

export interface IInnerGraphProps {
  data: ICanvasData;
  setData: TSetData;
  zoomPanSettings: IZoomPanSettings;
  setZoomPanSettings: TSetZoomPanSettings;
}

export const InnerGraph: React.FunctionComponent<IInnerGraphProps> = props => {
  const propsApi = usePropsAPI();

  const onNodeMouseDown = (evt: React.MouseEvent, node: ICanvasNode) => {
    props.setData(prevData => {
      const newNodes = prevData.nodes.map(n => {
        if (n.id === node.id && n.ports) {
          const newPorts = n.ports.map(p => {
            if (!p.isOutputDisabled) {
              return {
                ...p,
                state: GraphPortState.selected
              };
            }
            return {
              ...p
            };
          });
          return {
            ...n,
            ports: newPorts
          };
        }
        return {
          ...n
        };
      });
      return {
        ...prevData,
        nodes: newNodes
      };
    });
  };

  const onNodeClick = (_e: React.MouseEvent, node: ICanvasNode) => {
    propsApi.openSidePanel("node", node);
  };

  const onPortClick = (
    _e: React.MouseEvent,
    node: ICanvasNode,
    port: ICanvasPort
  ) => {
    propsApi.openSidePanel("port", { node, port });
  };

  const onCanvasMouseDown = () => {
    propsApi.dismissSidePanel();
  };

  return (
    <>
      <RegisterPanel name={"node"} config={new NodePanel(propsApi)} />
      <RegisterPanel name={"port"} config={new PortPanel()} />
      <Graph
        data={props.data}
        setData={props.setData}
        style={{ height: "800px", width: "calc(100vw - 325px)" }}
        onCanvasMouseDown={onCanvasMouseDown}
        onNodeMouseDown={onNodeMouseDown}
        zoomPanSettings={props.zoomPanSettings}
        setPanZoomPanSettings={props.setZoomPanSettings}
        onNodeClick={onNodeClick}
        onPortMouseUp={onPortClick}
        isAutoFitDisabled={true}
      />
    </>
  );
};
