import { Icon, PrimaryButton, Stack } from "office-ui-fabric-react";
import * as React from "react";
import { v4 } from "uuid";
import { ICanvasNode, usePropsAPI } from "../../src";
import { ICanvasPortCustomized } from "./modulePort";

interface INodePanelInnerProps {
  node: ICanvasNode;
}

export const NodePanelInner: React.FunctionComponent<INodePanelInnerProps> = props => {
  const { ports = [] } = props.node;
  const [portSettings, setPortSettings] = React.useState(ports);
  const [newPortName, setNewPortName] = React.useState<string>("");
  const propsAPI = usePropsAPI();

  const onNewPortNameChange: React.ChangeEventHandler<HTMLInputElement> = e => {
    setNewPortName(e.target.value);
  };

  const addInputPort = () => {
    const newPort = {
      id: v4(),
      name: newPortName,
      label: newPortName,
      shape: "modulePort",
      isOutputDisabled: true
    };

    propsAPI.addPort<ICanvasPortCustomized>(props.node.id, newPort);

    setPortSettings(prevPortSettings => [...prevPortSettings, newPort]);
    setNewPortName("");
  };

  const addOutputPort = () => {
    const newPort = {
      id: v4(),
      name: newPortName,
      label: newPortName,
      shape: "modulePort",
      isInputDisabled: true
    };

    propsAPI.addPort<ICanvasPortCustomized>(props.node.id, newPort);

    setPortSettings(prevPortSettings => [...prevPortSettings, newPort]);
    setNewPortName("");
  };

  return (
    <div>
      <h3>{props.node.name}</h3>
      <ul>
        {portSettings.map(portSetting => {
          const onDeletePort = () => {
            setPortSettings(prevPortSettings =>
              prevPortSettings.filter(s => s.id !== portSetting.id)
            );

            propsAPI.deletePort(portSetting.id, props.node.id);
          };

          return (
            <li key={portSetting.id}>
              <Stack horizontal={true}>
                <Stack.Item grow={true}>{portSetting.name}</Stack.Item>
                <Stack.Item>
                  <Icon iconName="Delete" onClick={onDeletePort} />
                </Stack.Item>
              </Stack>
            </li>
          );
        })}
        <li>
          <input value={newPortName} onChange={onNewPortNameChange} />
          <PrimaryButton onClick={addInputPort}>Add input port</PrimaryButton>
          <PrimaryButton onClick={addOutputPort}>Add output port</PrimaryButton>
        </li>
      </ul>
    </div>
  );
};
