import * as React from "react";
import {
  GraphPortConnectState,
  GraphPortState,
  ICanvasData,
  IPortConfig,
  useTheme
} from "../../src";
import { ICanvasPortCustomized } from "./modulePort";

interface IProps {
  data: ICanvasData;
  port: ICanvasPortCustomized;
  modulePort: IPortConfig;
  x: number;
  y: number;
}

export const Port: React.FunctionComponent<IProps> = props => {
  const { port, data, modulePort, x, y } = props;
  const { theme } = useTheme();

  const [displayTips, setDisplayTips] = React.useState("");
  const style = modulePort.getStyle
    ? modulePort.getStyle(port, data, theme)
    : {};

  const polygonPoints = `${x - 5} ${y}, ${x + 7} ${y}, ${x + 1} ${y + 8}`;

  const isConnectable = modulePort.getIsConnectable(port, data);

  const onPortMouseEnter = () => (evt: React.MouseEvent) => {
    if (!isConnectable && isConnectable !== undefined) {
      setDisplayTips("un connectable");
    } else {
      setDisplayTips(port.label);
    }
  };
  const onPortMouseLeave = () => (evt: React.MouseEvent) => {
    setDisplayTips("");
  };

  const tipsStyle: React.CSSProperties = {
    height: 20,
    boxSizing: "border-box",
    backgroundColor: theme.nodeFill,
    position: "absolute",
    padding: 2,
    border: `1px solid ${theme.nodeStroke}`,
    userSelect: "none",
    fontSize: 12
  };

  const renderCircle = (
    r: number,
    circleStyle: Partial<React.CSSProperties>
  ): React.ReactNode => {
    return <circle r={r} cx={x} cy={y} style={circleStyle} />;
  };

  return (
    <g>
      {/* draw tips */}
      {displayTips && (
        <foreignObject x={x + 12} y={y - 9} height="20" width="300">
          <div style={tipsStyle}>{displayTips}</div>
        </foreignObject>
      )}
      <g onMouseEnter={onPortMouseEnter()} onMouseLeave={onPortMouseLeave()}>
        {/* draw port */}
        {isConnectable === undefined ? ( // isConnectable === undefined is when the graph is not in connecting state
          <>
            {port.connectState === GraphPortConnectState.connectedAsTarget &&
            port.state !== GraphPortState.activated ? (
              <polygon points={polygonPoints} style={style} />
            ) : (
              renderCircle(6, style)
            )}
          </>
        ) : (
          <>
            {isConnectable &&
              renderCircle(18, { fill: theme.primaryColor, opacity: 0.2 })}
            {renderCircle(6, style)}
          </>
        )}
      </g>
    </g>
  );
};
