import { Dropdown, IDropdownOption } from "office-ui-fabric-react";
import * as React from "react";
import { useTheme } from "../../src";

interface IProps {}

export const ThemeControl: React.FunctionComponent<IProps> = () => {
  const options: IDropdownOption[] = [
    {
      key: "default",
      text: "default"
    },
    {
      key: "custom",
      text: "custom"
    }
  ];

  const [selectedKey, setSelectedKey] = React.useState("default");

  const { setTheme } = useTheme();

  const themes = {
    default: {
      controlPointColor: "#333333",
      primaryColor: "#0078D4",
      defaultColor: "#CCCCCC",
      borderColor: "#B3B0AD",
      defaultBorderColor: "#FFFFFF",
      unConnectableBgColor: "#E1DFDD",
      defaultBackgroundColor: "#FFFFFF",
      annotationBgColor: "#FFFFE0",
      portStroke: "#ccc",
      portFill: "#fff",
      connectedPortColor: "gray",
      nodeActivateFill: "#ffffff",
      nodeActivateStroke: "#0078D4",
      nodeFill: "#ffffff",
      nodeStroke: "#cccccc",
      contextMenuBackground: "#FFFFFF",
      contextMenuBorder: "#E1DFDD",
      contextMenuHoverBackground: "rgba(0, 120, 212, 0.05)",
      fontColor: "#000000",
      canvasBackground: "#EDEDED",
      edgeColor: "#ccc",
      edgeColorSelected: "#015cda"
    },
    custom: {
      controlPointColor: "red",
      primaryColor: "yellow",
      defaultColor: "blue",
      borderColor: "pink",
      defaultBorderColor: "green",
      unConnectableBgColor: "red",
      defaultBackgroundColor: "yellow",
      annotationBgColor: "blue",
      portStroke: "pink",
      portFill: "green",
      connectedPortColor: "red",
      nodeActivateFill: "yellow",
      nodeActivateStroke: "green",
      nodeFill: "blue",
      nodeStroke: "yellow",
      contextMenuBackground: "red",
      contextMenuBorder: "blue",
      contextMenuHoverBackground: "yellow",
      fontColor: "white",
      canvasBackground: "black",
      edgeColor: "#999",
      edgeColorSelected: "white"
    }
  };

  const onChange = (
    _e: React.FormEvent<HTMLDivElement>,
    option: IDropdownOption
  ) => {
    setTheme(themes[option.key]);
    setSelectedKey(option.key.toString());
  };

  return (
    <Dropdown options={options} selectedKey={selectedKey} onChange={onChange} />
  );
};
