// @ts-nocheck
import { Icon, Spinner } from "office-ui-fabric-react";
import * as React from "react";

import { ICanvasData, ICanvasEdge, ICanvasNode } from "../../src";
import * as data from "../data/sample4Graph.json";

// tslint:disable-next-line: cyclomatic-complexity
const getIconByCategory = (category: string): string => {
  const firstCategory = category.split("/")[0];

  switch (firstCategory) {
    case "Datasets":
    case "GenericCSV":
      return "Database";

    case "Data Transformation":
    case "Convert Data":
      return "TestUserSolid";

    case "Data Input and Output":
    case "Import Data":
      return "Dataflows";

    case "Machine Learning":
    case "Machine Learning Algorithms":
      return "MachineLearning";

    case "Model Training":
      return "ModelingView";

    case "Model Scoring & Evaluation":
      return "WebAppBuilderModule";

    case "Python Language":
    case "Python Script Step":
      return "PythonLanguage";

    case "Trained Models":
      return "PollResults";

    case "Transforms":
      return "Flow";

    // case "R Language":
    //   return RIcon;

    // case "Web Service":
    //   return webServiceIcon;

    // case "Feature Selection":
    //   return featureSelection;

    // case "Text Analytics":
    //   return textAnalytics;

    // case "Recommendation":
    //   return recommendation;

    // case "Statistical Functions":
    //   return StatisticalFunctions;

    default:
      return "";
  }
};

export const getSample4Data = (): ICanvasData => {
  const nodes: ICanvasNode[] = data.nodes.map((node, nodeIndex) => {
    return {
      id: node.id,
      shape: "module",
      x: node.x,
      y: node.y,
      name: node.name,
      data: {
        comment: "",
        iconName: getIconByCategory(node.category),
        statusIcon:
          nodeIndex > 3 ? (
            <Spinner />
          ) : (
            <Icon iconName="completed" style={{ color: "#57A300" }} />
          )
      },
      ports: node.ports.map((port, index) => {
        return {
          id: `port-${index}`,
          name: port.name,
          isInputDisabled: port.inputDataFormats.length === 0,
          isOutputDisabled: port.outputDataFormats.length === 0
        };
      })
    };
  });

  const edges: ICanvasEdge[] = data.edges.map(edge => {
    return {
      source: edge.source,
      target: edge.target,
      sourcePortId: `port-${edge.sourceAnchor}`,
      targetPortId: `port-${edge.targetAnchor}`,
      id: edge.id
    };
  });

  return {
    nodes,
    edges
  };
};
