import * as React from "react";
import {
  GraphPortConnectState,
  GraphPortState,
  ICanvasData,
  ICanvasPort,
  IPortConfig
} from "../../src";
import { Port } from "./Port";

export interface ICanvasPortCustomized extends ICanvasPort {
  label: string;
  // isConnectable: boolean;
}

export const modulePort: IPortConfig = {
  getStyle(portOriginal, data): Partial<React.CSSProperties> {
    const port: ICanvasPortCustomized = portOriginal as ICanvasPortCustomized;

    const strokeWidth = 2;
    let stroke = "#B3B0AD";
    let strokeDasharray = "";
    let fill = "#ffffff";

    switch (port.connectState) {
      case GraphPortConnectState.connectedAsSource:
      case GraphPortConnectState.connectedAsTarget:
        fill = "#B3B0AD";
        break;
      default:
    }

    switch (port.state) {
      case GraphPortState.activated:
      case GraphPortState.selected:
      case GraphPortState.connecting:
        fill = "#0078D4";
        stroke = "#0078D4";
        break;
      default:
    }

    if (port.state !== GraphPortState.connecting) {
      switch (modulePort.getIsConnectable(port, data)) {
        case true:
          fill = "#ffffff";
          stroke = "#0078D4";
          strokeDasharray = "3,2";
          break;
        case false:
          fill = "#E1DFDD";
          if (port.state === GraphPortState.activated) {
            stroke = "#B3B0AD";
          }
          break;
        default:
      }
    }

    return {
      stroke,
      strokeWidth,
      strokeDasharray,
      fill
    };
  },
  getIsConnectable(
    port: ICanvasPortCustomized,
    data: ICanvasData
  ): boolean | undefined {
    const { nodes = [] } = data;
    // for test
    let isOutputPort;
    nodes.map(node => {
      if (node.ports) {
        node.ports.map(p => {
          if (p.state === GraphPortState.connecting) {
            if (!p.isOutputDisabled) {
              isOutputPort = true;
            }
            if (!p.isInputDisabled) {
              isOutputPort = false;
            }
          }
        });
      }
    });
    if (isOutputPort === undefined) {
      return undefined;
    }
    if (isOutputPort) {
      return !port.isInputDisabled;
    } else {
      return !port.isOutputDisabled;
    }
  },
  render(args): React.ReactNode {
    const { model, data, x, y } = args;
    const port: ICanvasPortCustomized = model as ICanvasPortCustomized;

    return <Port data={data} port={port} modulePort={modulePort} x={x} y={y} />;
  }
};
